pub struct Prover<T: ProverState = Initialized> { /* private fields */ }Expand description
A prover instance.
Implementations
Sourceimpl Prover<Initialized>
impl Prover<Initialized>
Sourcepub async fn commit(
self,
config: TlsCommitConfig,
) -> Result<Prover<CommitAccepted>>
pub async fn commit( self, config: TlsCommitConfig, ) -> Result<Prover<CommitAccepted>>
Starts the TLS commitment protocol.
This initiates the TLS commitment protocol, including performing any necessary preprocessing operations.
Arguments
config- The TLS commitment configuration.
Sourceimpl Prover<CommitAccepted>
impl Prover<CommitAccepted>
Sourcepub fn connect<S: AsyncWrite + AsyncRead + Send + Unpin + 'static>(
self,
config: TlsClientConfig,
socket: S,
) -> Result<(TlsConnection, ProverFuture<S>)>
pub fn connect<S: AsyncWrite + AsyncRead + Send + Unpin + 'static>( self, config: TlsClientConfig, socket: S, ) -> Result<(TlsConnection, ProverFuture<S>)>
Connects to the server using the provided socket.
Returns a handle to the TLS connection, a future which returns the prover once the connection is closed and the TLS transcript is committed.
Arguments
config- The TLS client configuration.socket- The socket to the server.
Sourceimpl Prover<Committed>
impl Prover<Committed>
Sourcepub fn tls_transcript(&self) -> &TlsTranscript
pub fn tls_transcript(&self) -> &TlsTranscript
Returns the TLS transcript.
Sourcepub fn transcript(&self) -> &Transcript
pub fn transcript(&self) -> &Transcript
Returns the transcript.
Sourcepub async fn prove(&mut self, config: &ProveConfig) -> Result<ProverOutput>
pub async fn prove(&mut self, config: &ProveConfig) -> Result<ProverOutput>